@@ -1,8 +1,8 @@
-/* $Header: /usr/people/sam/tiff/tools/RCS/tiffdump.c,v 1.49 1996/03/29 16:38:33 sam Rel $ */
+/* $Header: /cvsroot/osrs/libtiff/tools/tiffdump.c,v 1.3 2003/09/02 13:28:09 warmerda Exp $ */
 
 /*
- * Copyright (c) 1988-1996 Sam Leffler
- * Copyright (c) 1991-1996 Silicon Graphics, Inc.
+ * Copyright (c) 1988-1997 Sam Leffler
+ * Copyright (c) 1991-1997 Silicon Graphics, Inc.
  *
  * Permission to use, copy, modify, distribute, and sell this software and 
  * its documentation for any purpose is hereby granted without fee, provided
@@ -64,8 +64,9 @@ char*	appname;
 char*	curfile;
 int	swabflag;
 int	bigendian;
-int	typeshift[13];	/* data type shift counts */
-long	typemask[13];	/* data type masks */
+int	typeshift[13];		/* data type shift counts */
+long	typemask[13];		/* data type masks */
+int	maxitems = 24;		/* maximum indirect data items to print */
 
 char*	bytefmt = "%s%#02x";		/* BYTE */
 char*	sbytefmt = "%s%d";		/* SBYTE */
@@ -85,7 +86,7 @@ extern	char* optarg;
 void
 usage()
 {
-	fprintf(stderr, "usage: %s [-h] [-o offset] file.tif ...\n", appname);
+	fprintf(stderr, "usage: %s [-h] [-o offset] [-m maxitems] file.tif ...\n", appname);
 	exit(-1);
 }
 
@@ -99,7 +100,7 @@ main(int argc, char* argv[])
 	bigendian = (*(char *)&one == 0);
 
 	appname = argv[0];
-	while ((c = getopt(argc, argv, "o:h")) != -1) {
+	while ((c = getopt(argc, argv, "m:o:h")) != -1) {
 		switch (c) {
 		case 'h':			/* print values in hex */
 			shortfmt = "%s%#x";
@@ -110,6 +111,9 @@ main(int argc, char* argv[])
 		case 'o':
 			diroff = (uint32) strtoul(optarg, NULL, 0);
 			break;
+		case 'm':
+			maxitems = strtoul(optarg, NULL, 0);
+			break;
 		default:
 			usage();
 		}
@@ -314,6 +318,7 @@ ReadDirectory(int fd, unsigned ix, uint32 off)
 		space = dp->tdir_count * datawidth[dp->tdir_type];
 		if (space <= 4) {
 			switch (dp->tdir_type) {
+			case TIFF_FLOAT:
 			case TIFF_UNDEFINED:
 			case TIFF_ASCII: {
 				unsigned char data[4];
@@ -347,8 +352,13 @@ ReadDirectory(int fd, unsigned ix, uint32 off)
 			unsigned char *data = (unsigned char *)_TIFFmalloc(space);
 			if (data) {
 				if (TIFFFetchData(fd, dp, data))
-					PrintData(stdout, dp->tdir_type,
-					    dp->tdir_count, data);
+					if (dp->tdir_count > maxitems) {
+						PrintData(stdout, dp->tdir_type,
+						    maxitems, data);
+						printf(" ...");
+					} else
+						PrintData(stdout, dp->tdir_type,
+						    dp->tdir_count, data);
 				_TIFFfree(data);
 			} else
 				Error("No space for data for tag %u",
@@ -423,6 +433,7 @@ static	struct tagname {
     { TIFFTAG_SUBIFD,		"SubIFD" },
     { TIFFTAG_INKSET,		"InkSet" },
     { TIFFTAG_INKNAMES,		"InkNames" },
+    { TIFFTAG_NUMBEROFINKS,	"NumberOfInks" },
     { TIFFTAG_DOTRANGE,		"DotRange" },
     { TIFFTAG_TARGETPRINTER,	"TargetPrinter" },
     { TIFFTAG_EXTRASAMPLES,	"ExtraSamples" },
@@ -435,6 +446,7 @@ static	struct tagname {
     { TIFFTAG_JPEGRESTARTINTERVAL,"JPEGRestartInterval" },
     { TIFFTAG_JPEGLOSSLESSPREDICTORS,"JPEGLosslessPredictors" },
     { TIFFTAG_JPEGPOINTTRANSFORM,"JPEGPointTransform" },
+    { TIFFTAG_JPEGTABLES,       "JPEGTables" },
     { TIFFTAG_JPEGQTABLES,	"JPEGQTables" },
     { TIFFTAG_JPEGDCTABLES,	"JPEGDCTables" },
     { TIFFTAG_JPEGACTABLES,	"JPEGACTables" },
@@ -452,7 +464,9 @@ static	struct tagname {
     { TIFFTAG_TILEDEPTH,	"TileDepth (Silicon Graphics)" },
     { 32768,			"OLD BOGUS Matteing tag" },
     { TIFFTAG_COPYRIGHT,	"Copyright" },
+    { TIFFTAG_ICCPROFILE,	"ICC Profile" },
     { TIFFTAG_JBIGOPTIONS,	"JBIG Options" },
+    { TIFFTAG_STONITS,		"StoNits" },
 };
 #define	NTAGS	(sizeof (tagnames) / sizeof (tagnames[0]))
 
@@ -567,8 +581,10 @@ PrintASCII(FILE* fd, uint32 cc, const unsigned char* cp)
 				break;
 		if (*tp)
 			fprintf(fd, "\\%c", *tp);
-		else
+		else if (*cp)
 			fprintf(fd, "\\%03o", *cp);
+		else
+			fprintf(fd, "\\0");
 	}
 }
 
